The alphaz-next library is a Python library that is designed to simplify the setup of RESTAPi using FastAPI & pydantic. It provides some usefull toolkit to setup Logger, Config, ...

## Installing Alphaz-Next

To install alphaz-next, if you already have Python, you can install with:

```
pip install alphaz-next
```

## How to import alphaz-next

To access alphaz-next and its functions import it in your Python code like this:

```
from alphaz-next import AlphaDatabase, AlphaLogger
from alphaz-next.models.config.config_settings import create_config_settings
```